@@ -15,7 +15,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
+ * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301
  * USA
  */
 
@@ -35,6 +35,11 @@ GType gog_grid_line_get_type (void);
 
 gboolean gog_grid_line_is_minor (GogGridLine *ggl);
 
+typedef GogView GogGridLineView;
+
+void gog_grid_line_view_render_stripes (GogView *view);
+void gog_grid_line_view_render_lines (GogView *view);
+
 G_END_DECLS
 
 #endif /* GOG_GRID_LINE_H */
